@@ -1,4 +1,4 @@
-// $Id: ArcBox.h,v 1.12 1999/08/19 11:27:03 andreas Exp $
+// $Id: ArcBox.h,v 1.13 2000/12/11 12:21:47 zeller Exp $
 // Arc boxes
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -81,7 +81,7 @@ protected:
 
 public:
     ArcBox(BoxDegrees start, BoxDegrees length,
-	   BoxCoordinate linethickness = 1, char * t = "ArcBox")
+	   BoxCoordinate linethickness = 1, const char * t = "ArcBox")
 	: LineBox(linethickness, t), _start(start), _length(length)
     {}
 
