@@ -1,8 +1,8 @@
-// $Id: BoxPoint.h,v 1.11 1998/03/25 12:42:27 zeller Exp $  -*- C++ -*-
+// $Id: BoxPoint.h,v 1.13 1999/09/27 06:05:27 andreas Exp $  -*- C++ -*-
 // BoxPoint class
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_BoxPoint_h
 #define _DDD_BoxPoint_h
@@ -91,6 +91,13 @@ public:
 	else
 	    return BoxPoint();
     }
+    BoxPoint operator - () const
+    {
+	if (isValid())
+	    return BoxPoint(-point[X], -point[Y]);
+	else
+	    return BoxPoint();
+    }
     BoxPoint operator * (const BoxPoint& p) const
     {
 	if (isValid() && p.isValid())
