@@ -1,4 +1,4 @@
-// $Id: DispValue.h,v 1.55 1999/09/27 08:05:47 andreas Exp $
+// $Id: DispValue.h,v 1.56 2000/06/06 20:32:37 andreas Exp $
 // Read and store type and value of a displayed expression
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -397,6 +397,9 @@ public:
 	_cached_box_change = cached_box_tics++;
     }
 
+    // Clear box caches for this and all children
+    void clear_box_cache();
+
     // Print plots to FILENAME
     void print_plots(const string& filename, 
 		     const PrintGC& gc = PostScriptPrintGC()) const;
