@@ -1,4 +1,4 @@
-// $Id: InitImage.h,v 1.3 1999/08/19 11:27:36 andreas Exp $ -*- C++ -*-
+// $Id: InitImage.h,v 1.4 2000/12/11 12:21:47 zeller Exp $ -*- C++ -*-
 // Create an XImage from bitmap data
 
 // Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
@@ -44,7 +44,7 @@ extern XImage *CreateImageFromBitmapData(unsigned char *bits,
 					 int width, int height);
 
 // Install IMAGE in Motif cache
-Boolean InstallImage(XImage *image, char *name);
+Boolean InstallImage(XImage *image, const char *name);
 
 // Install bitmap in Motif cache
 Boolean InstallBitmap(unsigned char *bits, int width, int height, char *name);
