@@ -1,4 +1,4 @@
-// $Id: LetNode.h,v 1.15 2000/02/16 11:32:29 andreas Exp $
+// $Id: LetNode.h,v 1.16 2000/12/11 12:21:47 zeller Exp $
 // LET..IN construct in VSL
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -92,7 +92,7 @@ protected:
     }
 
     // Never called
-    char *func_name() const       { assert(0); return "let"; }
+    const char *func_name() const       { assert(0); return "let"; }
     const Box *call(Box *) const  { assert(0); return 0; }
 
 private:
@@ -100,7 +100,7 @@ private:
 
 public:
     // Constructor
-    LetNode(VSLNode *p, VSLNode *a, VSLNode *b, char *type = "LetNode"):
+    LetNode(VSLNode *p, VSLNode *a, VSLNode *b, const char *type = "LetNode"):
 	CallNode(new FixListNode(a, b), type),
 	_node_pattern(p),
 	_box_pattern(0),
