@@ -1,4 +1,4 @@
-// $Id: ListNode.h,v 1.15 2000/02/16 11:32:29 andreas Exp $
+// $Id: ListNode.h,v 1.17 2000/12/11 12:21:47 zeller Exp $
 // ListNode class
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -69,7 +69,7 @@ private:
     ListNode& operator = (const ListNode&) { assert(0); return *this; }
 
 public:
-    ListNode(VSLNode *hd, VSLNode *tl, char *type = "ListNode");
+    ListNode(VSLNode *hd, VSLNode *tl, const char *type = "ListNode");
     VSLNode *dup() const { return new ListNode(*this); }
 
     // Destructor (including args)
@@ -107,6 +107,7 @@ public:
     void uncompilePatterns(VSLDef *cdef) const;
     int resolveName(VSLDef *cdef, VSLNode **node, string& name, unsigned id);
     int _resolveNames(VSLDef *cdef, unsigned base);
+    void rebind(const class VSLLib *);
     string firstName() const;
 
     // Append to list
