@@ -1,4 +1,4 @@
-// $Id: MString.h,v 1.25 1999/08/19 11:27:40 andreas Exp $
+// $Id: MString.h,v 1.28 2000/12/11 12:21:47 zeller Exp $
 // Simple interface to Motif composite strings
 
 // Copyright (C) 1995-1998 Technische Universitaet Braunschweig, Germany.
@@ -52,20 +52,22 @@ private:
 
 public:
     // Constructors
-    MString(char *text = "",
-	    XmStringCharSet charset = MSTRING_DEFAULT_CHARSET):
-	_mstring(text ? XmStringCreateLtoR(text, charset) : 0)
-    {
-	assert(OK());
-    }
-
-    MString(const char *text,
+    MString(const char *text = "",
 	    XmStringCharSet charset = MSTRING_DEFAULT_CHARSET):
 	_mstring(text ? XmStringCreateLtoR((char *)text, charset) : 0)
     {
 	assert(OK());
     }
 
+#if 0
+    MString(char *text,
+	    XmStringCharSet charset = MSTRING_DEFAULT_CHARSET):
+	_mstring(text ? XmStringCreateLtoR(text, charset) : 0)
+    {
+	assert(OK());
+    }
+#endif
+
     MString(const string& text,
 	    XmStringCharSet charset = MSTRING_DEFAULT_CHARSET):
 	_mstring(XmStringCreateLtoR((char *)text, charset))
@@ -229,7 +231,10 @@ inline MString operator + (const MString& m1, const MString& m2)
     if (m2.isNull())
 	return m1;
 
-    return MString(XmStringConcat(m1.xmstring(), m2.xmstring()), true);
+    XmString tmp = XmStringConcat(m1.xmstring(), m2.xmstring());
+    MString ret(tmp, true);
+    XmStringFree(tmp);
+    return ret;
 }
 
 inline MString operator + (const MString& m, const char *s)
