@@ -1,33 +1,33 @@
-// $Id: MemCheck.h,v 1.9 1999/08/19 11:27:44 andreas Exp $ -*- C++ -*-
+// $Id: MemCheck.h,v 1.12 2000/12/11 12:21:47 zeller Exp $ -*- C++ -*-
 // Memory Checker
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@gnu.org>.
 // 
-// This file is part of the ICE Library.
+// This file is part of DDD.
 // 
-// The ICE Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The ICE Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the ICE Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// ICE is the incremental configuration environment.
-// For details, see the ICE World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ice/',
-// or send a mail to the ICE developers <ice@ips.cs.tu-bs.de>.
+// DDD is the data display debugger.
+// For details, see the DDD World-Wide-Web page, 
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
-#ifndef _ICE_MemCheck_h
-#define _ICE_MemCheck_h
+#ifndef _DDD_MemCheck_h
+#define _DDD_MemCheck_h
 
 #ifdef __GNUG__
 #pragma interface
@@ -101,7 +101,7 @@ private:
 
     static MemCheckHeader *morecore(unsigned nunits);
     static void _free(MemCheckHeader *bp);
-    static void validate(MemCheckHeader *bp, char *src);
+    static void validate(MemCheckHeader *bp, const char *src);
 
     // initialize
     static void init();
@@ -113,8 +113,11 @@ public:
     // Free block at p
     static void free(void *p);
 
+    // Make sure p points to an allocated block
+    static void check(void *p);
+
     // Issue a map of all allocated blocks (starting with block #start)
-    static void map(ostream& os, unsigned start = 0, char *prefix = "");
+    static void map(ostream& os, unsigned start = 0, const char *prefix = "");
 
     // Return current block number
     static unsigned tic() { return tics; }
@@ -148,7 +151,7 @@ private:
     unsigned start;
 
 public:
-    MemChecker(char *pfx = ""):
+    MemChecker(const char *pfx = ""):
         prefix(pfx), start(MemCheck::tic())
     {}
 
@@ -173,5 +176,5 @@ inline void MemCheck::init()
     }
 }
 
-#endif // _ICE_MemCheck_h
+#endif // _DDD_MemCheck_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
