@@ -1,4 +1,4 @@
-// $Id: PlotAgent.h,v 1.16 1999/08/19 11:27:46 andreas Exp $ -*- C++ -*-
+// $Id: PlotAgent.h,v 1.18 2000/12/20 12:30:24 zeller Exp $ -*- C++ -*-
 // Gnuplot interface
 
 // Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
@@ -77,9 +77,9 @@ protected:
     void add_y(double y);
 
     void reset();
-    string var(char *name, double min, double max);
+    string var(const char *name, double min, double max);
 
-    virtual void dispatch(int type, char *data, int length);
+    virtual void dispatch(int type, const char *data, int length);
 
 public:
     static string plot_2d_settings;
@@ -89,7 +89,8 @@ public:
     PlotAgent(XtAppContext app_context, const string& pth,
 	      unsigned nTypes = PlotAgent_NTypes)
 	: LiterateAgent(app_context, pth, nTypes),
-	  files(), titles(), plot_os(), ndim(0), 
+	  files(), titles(), values(), dims(),
+	  plot_os(), ndim(0), 
 	  x_min(0.0), x_max(0.0),
 	  y_min(0.0), y_max(0.0),
 	  v_min(0.0), v_max(0.0),
