@@ -1,4 +1,4 @@
-// $Id: PosBuffer.h,v 1.28 1999/08/19 11:27:47 andreas Exp $
+// $Id: PosBuffer.h,v 1.29 2000/05/24 17:42:18 andreas Exp $
 // Filter position information from GDB output.
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -67,6 +67,11 @@ protected:
     void filter_pydb(string& answer);
     void filter_perl(string& answer);
 
+    // Filter all lines from ANSWER beginning with current line.  This
+    // is required to suppress the line number output after a
+    // `stopping in' message.
+    void filter_line(string& answer);
+
 public:
     bool check_pc;		// Whether to search for PC
     bool check_func;		// Whether to search for function name
