@@ -1,4 +1,4 @@
-// $Id: XErrorB.h,v 1.4 1999/08/19 11:28:08 andreas Exp $ -*- C++ -*-
+// $Id: XErrorB.h,v 1.5 2000/12/20 12:30:24 zeller Exp $ -*- C++ -*-
 // Block X errors
 
 // Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
@@ -48,6 +48,20 @@ class XErrorBlocker {
     static int handler(Display *, XErrorEvent *);
     static XErrorBlocker *active;
 
+    XErrorBlocker(const XErrorBlocker&)
+	: _display(0), _error_occurred(false), _event(), 
+	  saved_handler(), saved_active(0)
+    {
+	assert(0);
+    }
+
+    XErrorBlocker& operator=(const XErrorBlocker&)
+    {
+	assert(0);
+	return *this;
+    }
+	
+
 protected:
     virtual int handle(Display *, XErrorEvent *);
     virtual void sync() const { XSync(_display, False); }
