@@ -1,34 +1,34 @@
-// $Id: acconfig.h.in,v 1.43 2000/01/17 14:53:41 andreas Exp $ -*- C++ -*-
+// $Id: acconfig.h.in,v 1.46 2000/06/09 13:09:18 andreas Exp $ -*- C++ -*-
 // General configuration file.
 
 // Copyright (C) 1995-1999 Technische Universitaet Braunschweig, Germany.
 // Copyright (C) 2000 Universitaet Passau, Germany.
 // Written by Andreas Zeller <zeller@gnu.org>.
 // 
-// This file is part of the ICE Library.
+// This file is part of DDD.
 // 
-// The ICE Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The ICE Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the ICE Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// ICE is the incremental configuration environment.
-// For details, see the ICE World-Wide-Web page, 
-// http://www.cs.tu-bs.de/softech/ice/,
-// or send a mail to the ICE developers <ice@ips.cs.tu-bs.de>.
+// DDD is the data display debugger.
+// For details, see the DDD World-Wide-Web page, 
+// http://www.gnu.org/software/ddd/,
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
-#ifndef _ICE_config_h
-#define _ICE_config_h
+#ifndef _DDD_config_h
+#define _DDD_config_h
 // @TOP@
 
 // Descriptive text for C preprocessor macros that autoconf may define.
@@ -80,6 +80,15 @@
 /* Define if your C++ library has an ostrstream::frozen() function. */
 #undef HAVE_FROZEN_OSTRSTREAM
 
+/* Define if your C++ library has an ostrstreambuf::frozen() function. */
+#undef HAVE_FROZEN_OSTRSTREAMBUF
+
+/* Define if your C++ library has an ostrstream::freeze() function. */
+#undef HAVE_FREEZE_OSTRSTREAM
+
+/* Define if your C++ library has an ostrstreambuf::freeze() function. */
+#undef HAVE_FREEZE_OSTRSTREAMBUF
+
 /* Define if your C++ compiler supports long long types. */
 #undef HAVE_LONG_LONG
 
@@ -132,6 +141,10 @@
 /* Define if the regex_t type has a re_nsub member, according to POSIX.2 */
 #undef HAVE_REGEX_T_RE_NSUB
 
+/* Define if Motif selection dialogs own their selection list, i.e. it
+   must not be freed after setting. */
+#undef MOTIF_DIALOGS_OWN_SELECTION_LIST
+
 /* Define if ostrstream::pcount() is increased by 1 after accessing the
    string via ostrstream::str(), as in the SGI C++ I/O library. */
 #undef OSTRSTREAM_PCOUNT_BROKEN
@@ -166,6 +179,15 @@
 /* Define if you want the manual to be compiled into the executable. */
 #undef WITH_BUILTIN_MANUAL
 
+/* Define if you want the DDD news to be compiled into the executable. */
+#undef WITH_BUILTIN_NEWS
+
+/* Define if you want the DDD license to be compiled into the executable. */
+#undef WITH_BUILTIN_LICENSE
+
+/* Define if you want the DDD VSL library to be compiled into DDD. */
+#undef WITH_BUILTIN_VSLLIB
+
 /* Define if you want the app-defaults file to be compiled into the
    executable. */
 #undef WITH_BUILTIN_APP_DEFAULTS
@@ -248,6 +270,9 @@
 /* Define if memset is declared in string.h. */
 #undef HAVE_MEMSET_DECL
 
+/* Define if mkstemp is declared in stdlib.h. */
+#undef HAVE_MKSTEMP_DECL
+
 /* Define if pclose is declared in stdio.h. */
 #undef HAVE_PCLOSE_DECL
 
@@ -371,6 +396,9 @@
 /* Define if times is declared in sys/times.h. */
 #undef HAVE_TIMES_DECL
 
+/* Define if tmpfile is declared in stdio.h. */
+#undef HAVE_TMPFILE_DECL
+
 /* Define if uname is declared in sys/utsname.h. */
 #undef HAVE_UNAME_DECL
 
@@ -383,5 +411,5 @@
 /* Define if waitpid is declared in sys/wait.h. */
 #undef HAVE_WAITPID_DECL
 
-#endif // _ICE_config_h
+#endif // _DDD_config_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
