@@ -1,7 +1,8 @@
-// $Id: filetype.h,v 1.14 1999/08/19 11:28:34 andreas Exp $ -*- C++ -*-
+// $Id: filetype.h,v 1.15 2000/05/29 08:38:40 andreas Exp $ -*- C++ -*-
 // Determine file type
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Copyright (C) 2000 Universitaet Passau, Germany.
 // Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
@@ -42,6 +43,9 @@ bool is_binary_file(const string& file_name);
 // True if FILE_NAME is an executable binary file
 bool is_exec_file(const string& file_name);
 
+// True if FILE_NAME is an executable binary debuggee
+bool is_debuggee_file(const string& file_name);
+
 // True if FILE_NAME is an executable file or script
 bool is_cmd_file(const string& file_name);
 
