@@ -1,4 +1,4 @@
-// $Id: options.h,v 1.57 1999/08/19 11:28:46 andreas Exp $ -*- C++ -*-
+// $Id: options.h,v 1.59 2001/01/15 15:51:05 zeller Exp $ -*- C++ -*-
 // Save and edit DDD options
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
@@ -75,8 +75,9 @@ extern void sourceToggleFindWordsOnlyCB     (Widget, XtPointer, XtPointer);
 extern void sourceToggleFindCaseSensitiveCB (Widget, XtPointer, XtPointer);
 extern void sourceToggleCacheSourceFilesCB  (Widget, XtPointer, XtPointer);
 extern void sourceToggleCacheMachineCodeCB  (Widget, XtPointer, XtPointer);
-extern void sourceToggleAllRegistersCB      (Widget, XtPointer, XtPointer);
 extern void sourceToggleDisplayLineNumbersCB(Widget, XtPointer, XtPointer);
+extern void sourceSetIntRegistersCB         (Widget, XtPointer, XtPointer);
+extern void sourceSetAllRegistersCB         (Widget, XtPointer, XtPointer);
 extern void sourceSetDisplayGlyphsCB        (Widget, XtPointer, XtPointer);
 extern void sourceSetUseSourcePathCB        (Widget, XtPointer, XtPointer);
 extern void sourceSetTabWidthCB             (Widget, XtPointer, XtPointer);
@@ -95,6 +96,7 @@ extern void graphToggleShowAnnotationsCB    (Widget, XtPointer, XtPointer);
 extern void graphToggleShowDependentTitlesCB(Widget, XtPointer, XtPointer);
 extern void graphToggleClusterDisplaysCB    (Widget, XtPointer, XtPointer);
 extern void graphSetGridSizeCB              (Widget, XtPointer, XtPointer);
+extern void graphSetDisplayPlacementCB      (Widget, XtPointer, XtPointer);
 
 extern void dddToggleGroupIconifyCB         (Widget, XtPointer, XtPointer);
 extern void dddToggleUniconifyWhenReadyCB   (Widget, XtPointer, XtPointer);
